@@ -1,4 +1,4 @@
-binomial.dissimilarityCAR <- function(formula, data=NULL,  trials, W, Z, W.binary=TRUE, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, verbose=TRUE)
+binomial.dissimilarityCAR <- function(formula, data=NULL,  trials, W, Z, W.binary=TRUE, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, MALA=TRUE, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -23,6 +23,11 @@ which.miss <- frame.results$which.miss
 n.miss <- frame.results$n.miss  
 
 
+#### Check on MALA argument
+    if(length(MALA)!=1) stop("MALA is not length 1.", call.=FALSE)
+    if(!is.logical(MALA)) stop("MALA is not logical.", call.=FALSE)  
+
+
 #### Check and format the trials argument
     if(sum(is.na(trials))>0) stop("the numbers of trials has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(trials)) stop("the numbers of trials has non-numeric values.", call.=FALSE)
@@ -64,10 +69,10 @@ q <- length(Z)
 
 #### Priors
     if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
-    if(is.null(prior.var.beta)) prior.var.beta <- rep(1000, p)
+    if(is.null(prior.var.beta)) prior.var.beta <- rep(100000, p)
     if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)
-prior.beta.check(prior.mean.beta, prior.var.beta, p)
-prior.var.check(prior.tau2)
+common.prior.beta.check(prior.mean.beta, prior.var.beta, p)
+common.prior.var.check(prior.tau2)
 
 
 #### Compute the blocking structure for beta     
@@ -129,8 +134,6 @@ accept.all <- accept
 proposal.sd.beta <- 0.01
 proposal.sd.phi <- 0.1
 proposal.sd.alpha <- 0.02 * alpha.max
-proposal.corr.beta <- solve(t(X.standardised) %*% X.standardised)
-chol.proposal.corr.beta <- chol(proposal.corr.beta) 
 tau2.posterior.shape <- prior.tau2[1] + 0.5 * K
 
 
@@ -221,7 +224,13 @@ det.Q <- sum(log(diag(chol.spam(Q))))
 	## Sample from phi
 	####################
     beta.offset <- X.standardised %*% beta + offset
-    temp1 <- binomialcarupdate(Wtriplet=W.triplet, Wbegfin=W.begfin, Wtripletsum=W.triplet.sum, nsites=K, phi=phi, tau2=tau2, y=Y.miss, failures=failures.miss, trials=trials, phi_tune=proposal.sd.phi, rho=rho, offset=beta.offset, which.miss)
+        if(MALA)
+        {
+        temp1 <- binomialcarupdateMALA(Wtriplet=W.triplet, Wbegfin=W.begfin, Wtripletsum=W.triplet.sum, nsites=K, phi=phi, tau2=tau2, y=Y.miss, failures=failures.miss, trials=trials, phi_tune=proposal.sd.phi, rho=rho, offset=beta.offset, which.miss)
+        }else
+        {
+        temp1 <- binomialcarupdateRW(Wtriplet=W.triplet, Wbegfin=W.begfin, Wtripletsum=W.triplet.sum, nsites=K, phi=phi, tau2=tau2, y=Y.miss, failures=failures.miss, phi_tune=proposal.sd.phi, rho=rho, offset=beta.offset, which.miss)
+        }
     phi <- temp1[[1]]
     phi <- phi - mean(phi)
     accept[3] <- accept[3] + temp1[[2]]
@@ -394,6 +403,12 @@ CPO <- rep(NA, K)
 LMPL <- sum(log(CPO), na.rm=TRUE)   
      
      
+#### Compute the % deviance explained
+fit.null <- glm(cbind(Y, failures)~1, offset=offset, family="binomial")$fitted.values
+deviance.null <- -2 * sum(dbinom(x=Y[which(!is.na(Y))], size=trials[which(!is.na(Y))], prob=fit.null, log=TRUE), na.rm=TRUE)
+percent_dev_explained <- 100 * (deviance.null - deviance.fitted) / deviance.null
+
+
 #### transform the parameters back to the origianl covariate scale.
 samples.beta.orig <- common.betatransform(samples.beta, X.indicator, X.mean, X.sd, p, FALSE)
 
@@ -491,8 +506,8 @@ W.posterior <- array(NA, c(K,K))
 
 #### Compile and return the results
 loglike <- (-0.5 * deviance.fitted)
-modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike)
-names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood")
+modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike, percent_dev_explained)
+names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood", "Percentage deviance explained")
     if(W.binary)
     {
     model.string <- c("Likelihood model - Binomial (logit link function)", "\nRandom effects model - Binary dissimilarity CAR", "\nDissimilarity metrics - ", rownames(summary.alpha), "\n")     
