@@ -1,4 +1,4 @@
-poisson.bymCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, prior.sigma2=NULL, verbose=TRUE)
+poisson.bymCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, prior.sigma2=NULL, MALA=TRUE, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -23,14 +23,19 @@ which.miss <- frame.results$which.miss
 n.miss <- frame.results$n.miss  
 
 
+#### Check on MALA argument
+    if(length(MALA)!=1) stop("MALA is not length 1.", call.=FALSE)
+    if(!is.logical(MALA)) stop("MALA is not logical.", call.=FALSE)  
+
+
 #### Priors
     if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
-    if(is.null(prior.var.beta)) prior.var.beta <- rep(1000, p)
+    if(is.null(prior.var.beta)) prior.var.beta <- rep(100000, p)
     if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)
     if(is.null(prior.sigma2)) prior.sigma2 <- c(1, 0.01)
-prior.beta.check(prior.mean.beta, prior.var.beta, p)
-prior.var.check(prior.tau2)
-prior.var.check(prior.sigma2)
+common.prior.beta.check(prior.mean.beta, prior.var.beta, p)
+common.prior.var.check(prior.tau2)
+common.prior.var.check(prior.sigma2)
 
 
 #### Compute the blocking structure for beta     
@@ -90,8 +95,6 @@ accept <- accept.all
 proposal.sd.beta <- 0.01
 proposal.sd.phi <- 0.1
 proposal.sd.theta <- 0.1
-proposal.corr.beta <- solve(t(X.standardised) %*% X.standardised)
-chol.proposal.corr.beta <- chol(proposal.corr.beta) 
 sigma2.posterior.shape <- prior.sigma2[1] + 0.5 * K
 
 
@@ -158,7 +161,13 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
     ## Sample from phi
     ####################
     beta.offset <- X.standardised %*% beta + theta + offset
-    temp1 <- poissoncarupdate(Wtriplet=W.triplet, Wbegfin=W.begfin, W.triplet.sum, nsites=K, phi=phi, tau2=tau2, y=Y.miss, phi_tune=proposal.sd.phi, rho=1, offset=beta.offset, which.miss)
+        if(MALA)
+        {
+        temp1 <- poissoncarupdateMALA(Wtriplet=W.triplet, Wbegfin=W.begfin, W.triplet.sum, nsites=K, phi=phi, tau2=tau2, y=Y.miss, phi_tune=proposal.sd.phi, rho=1, offset=beta.offset, which.miss)
+        }else
+        {
+        temp1 <- poissoncarupdateRW(Wtriplet=W.triplet, Wbegfin=W.begfin, W.triplet.sum, nsites=K, phi=phi, tau2=tau2, y=Y.miss, phi_tune=proposal.sd.phi, rho=1, offset=beta.offset, which.miss)
+        }
     phi <- temp1[[1]]
     phi[which(islands==1)] <- phi[which(islands==1)] - mean(phi[which(islands==1)])
     accept[3] <- accept[3] + temp1[[2]]
@@ -169,8 +178,14 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
     ####################
     ## Sample from theta
     ####################
-    beta.offset <- as.numeric(X.standardised %*% beta) + phi + offset        
-    temp2 <- poissonindepupdate(nsites=K, theta=theta, sigma2=sigma2, y=Y.miss, theta_tune=proposal.sd.theta, offset=beta.offset, which.miss) 
+    beta.offset <- as.numeric(X.standardised %*% beta) + phi + offset
+        if(MALA)
+        {
+        temp2 <- poissonindepupdateMALA(nsites=K, theta=theta, sigma2=sigma2, y=Y.miss, theta_tune=proposal.sd.theta, offset=beta.offset, which.miss) 
+        }else
+        {
+        temp2 <- poissonindepupdateRW(nsites=K, theta=theta, sigma2=sigma2, y=Y.miss, theta_tune=proposal.sd.theta, offset=beta.offset, which.miss) 
+        }
     theta <- temp2[[1]]
     theta <- theta - mean(theta)    
     accept[5] <- accept[5] + temp2[[2]]
@@ -306,6 +321,12 @@ CPO <- rep(NA, K)
 LMPL <- sum(log(CPO), na.rm=TRUE)  
 
      
+#### Compute the % deviance explained
+fit.null <- glm(Y~1, offset=offset, family="poisson")$fitted.values
+deviance.null <- -2 * sum(dpois(x=Y[which(!is.na(Y))], lambda=fit.null, log=TRUE), na.rm=TRUE)
+percent_dev_explained <- 100 * (deviance.null - deviance.fitted) / deviance.null
+
+
 #### transform the parameters back to the origianl covariate scale.
 samples.beta.orig <- common.betatransform(samples.beta, X.indicator, X.mean, X.sd, p, FALSE)
 
@@ -340,8 +361,8 @@ residuals <- data.frame(response=response.residuals, pearson=pearson.residuals,
 
 #### Compile and return the results
 loglike <- (-0.5 * deviance.fitted)
-modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike)
-names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood")
+modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike, percent_dev_explained)
+names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood", "Percentage deviance explained")
 model.string <- c("Likelihood model - Poisson (log link function)", "\nRandom effects model - BYM CAR\n")
 if(n.miss==0) samples.Y = NA
 
